==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/DataLegendSeriesContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesContextDescription } from "./DataLegendSeriesContextDescription";
/**
 * @hidden
 */
export let DataLegendSeriesContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSeriesContextDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSeriesContextDescriptionMetadata.a == null) {
                DataLegendSeriesContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSeriesContextDescriptionMetadata.c(DataLegendSeriesContextDescriptionMetadata.a);
            }
            if (a.k(DataLegendSeriesContextDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataLegendSeriesContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SeriesGroup", "ExportedType:string:DataLegendSeriesGroup");
            a.item("SeriesGroup@names", "Category;Range;Financial;Indicator;Polar;Radial;Scatter;Stacked;Shape;Geographic");
        }
        static d(a) {
            DataLegendSeriesContextDescriptionMetadata.b(a);
            a.ad("DataLegendSeriesContext", () => new DataLegendSeriesContextDescription());
            a.ac("DataLegendSeriesContext", DataLegendSeriesContextDescriptionMetadata.a);
        }
    }
    DataLegendSeriesContextDescriptionMetadata.$t = markType(DataLegendSeriesContextDescriptionMetadata, 'DataLegendSeriesContextDescriptionMetadata');
    DataLegendSeriesContextDescriptionMetadata.a = null;
    return DataLegendSeriesContextDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/DataLegendSeriesContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesContextDescription } from "./DataLegendSeriesContextDescription";
/**
 * @hidden
 */
export let DataLegendSeriesContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSeriesContextDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSeriesContextDescriptionMetadata.a == null) {
                DataLegendSeriesContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSeriesContextDescriptionMetadata.c(DataLegendSeriesContextDescriptionMetadata.a);
            }
            if (a.k(DataLegendSeriesContextDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataLegendSeriesContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("SeriesFamily", "String");
        }
        static d(a) {
            DataLegendSeriesContextDescriptionMetadata.b(a);
            a.ae("DataLegendSeriesContext", () => new DataLegendSeriesContextDescription());
            a.ad("DataLegendSeriesContext", DataLegendSeriesContextDescriptionMetadata.a);
        }
    }
    DataLegendSeriesContextDescriptionMetadata.$t = markType(DataLegendSeriesContextDescriptionMetadata, 'DataLegendSeriesContextDescriptionMetadata');
    DataLegendSeriesContextDescriptionMetadata.a = null;
    return DataLegendSeriesContextDescriptionMetadata;
})();
